==> 5.0.5.tar.gz: lib/spectus_in_app_purchase.dart <==

import 'dart:async';
import 'dart:ffi';

import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';

class SpectusInAppPurchase {
  static const MethodChannel _channel =
      const MethodChannel('spectus_in_app_purchase');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<String> startInAppPurchaseWith({String productID, bool isSubscription, String iosAppSecret}) async
  {
    final String transactionID = await _channel.invokeMethod('startInAppPurchaseWith',
        {
          "productID":productID,
          "isSubscription": isSubscription,
          "iosAppSecret" : iosAppSecret
        }
    );

    if (transactionID == null) {
      return "NA";
    } else {
      return transactionID;
    }
  }

  static Future<String> getProductDetailsOf({String productID, bool isSubscription, String iosAppSecret}) async
  {
    final Map<String, String> productObject = await _channel.invokeMethod('getProductDetailsOf',
        {
          "productID":productID,
          "isSubscription": isSubscription,
          "iosAppSecret" : iosAppSecret
        }
    );

    print('DART FILE =>\n' + productObject.toString() + '\n===============\n');
    return productObject.toString();
  }

  static Future<List<Map<String, String>>> getSKUProductListWith({List<String> productIDs, bool isSubscription}) async
  {
    final String productsInfo = await _channel.invokeMethod('getSKUProductListWith',
        {
          "productIDs":productIDs,
          "isSubscription": isSubscription
        }
    );
    print("DART => Product List count");
    print("RESPONSE => " + productsInfo);
    List<Map<String, String>> array = [];
    var mainArray = split(productsInfo, '&^&');
    print("Main Count => " + mainArray.length.toString());
    mainArray.forEach((singleItem) {
      print("SPLIT 1 => " + singleItem);
      if (!singleItem.isEmpty) {
        var info = split(singleItem, '&&');
        print("SPLIT 2 Array => " + info.length.toString());
        var productObject = {
          "amount" : info[0],
          "currency_code" : info[1],
          "title" : info[2],
          "description" : info[3],
          "product_id" : info[4]
        }; //SEQUENCE: Price && Currency Code && Title && Description && SKU (product_id)
        array.add(productObject);
      }
    });

    print("For Each Finished => ");
    return array;
  }

  static Future<String> startRestorePurchase() async
  {
    final String transactionID = await _channel.invokeMethod('startRestorePurchase');
    if (transactionID == null) {
      return "NA";
    } else {
      return transactionID;
    }
  }
}

List<String> split(String string, String separator, {int max = 0}) {
  var result = List<String>();

  if (separator.isEmpty) {
    result.add(string);
    return result;
  }

  while (true) {
    var index = string.indexOf(separator, 0);
    if (index == -1 || (max > 0 && result.length >= max)) {
      result.add(string);
      break;
    }

    result.add(string.substring(0, index));
    string = string.substring(index + separator.length);
  }

  return result;
}

==> 5.1.1.tar.gz: lib/spectus_in_app_purchase.dart <==

import 'dart:async';
import 'dart:ffi';

import 'package:flutter/cupertino.dart';
import 'package:flutter/services.dart';

class SpectusInAppPurchase {
  static const MethodChannel _channel =
      const MethodChannel('spectus_in_app_purchase');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<String> startInAppPurchaseWith({String productID, bool isSubscription, String iosAppSecret}) async
  {
    final String transactionID = await _channel.invokeMethod('startInAppPurchaseWith',
        {
          "productID":productID,
          "isSubscription": isSubscription,
          "iosAppSecret" : iosAppSecret
        }
    );

    if (transactionID == null) {
      return "NA";
    } else {
      return transactionID;
    }
  }

  static Future<String> getProductDetailsOf({String productID, bool isSubscription, String iosAppSecret}) async
  {
    final String productObject = await _channel.invokeMethod('getProductDetailsOf',
        {
          "productID":productID,
          "isSubscription": isSubscription,
          "iosAppSecret" : iosAppSecret
        }
    );

    print('DART FILE =>\n' + productObject + '\n===============\n');
    return productObject;
  }

  static Future<List<Map<String, String>>> getSKUProductListWith({List<String> productIDs, bool isSubscription}) async
  {
    final String productsInfo = await _channel.invokeMethod('getSKUProductListWith',
        {
          "productIDs":productIDs,
          "isSubscription": isSubscription
        }
    );
    print("DART => Product List count");
    print("RESPONSE => " + productsInfo);
    List<Map<String, String>> array = [];
    var mainArray = split(productsInfo, '&^&');
    print("Main Count => " + mainArray.length.toString());
    mainArray.forEach((singleItem) {
      print("SPLIT 1 => " + singleItem);
      if (!singleItem.isEmpty) {
        var info = split(singleItem, '&&');
        print("SPLIT 2 Array => " + info.length.toString());
        var productObject = {
          "amount" : info[0],
          "currency_code" : info[1],
          "title" : info[2],
          "description" : info[3],
          "product_id" : info[4]
        }; //SEQUENCE: Price && Currency Code && Title && Description && SKU (product_id)
        array.add(productObject);
      }
    });

    print("For Each Finished => ");
    return array;
  }

  static Future<String> startRestorePurchase() async
  {
    final String transactionID = await _channel.invokeMethod('startRestorePurchase');
    if (transactionID == null) {
      return "NA";
    } else {
      return transactionID;
    }
  }
}

List<String> split(String string, String separator, {int max = 0}) {
  var result = List<String>();

  if (separator.isEmpty) {
    result.add(string);
    return result;
  }

  while (true) {
    var index = string.indexOf(separator, 0);
    if (index == -1 || (max > 0 && result.length >= max)) {
      result.add(string);
      break;
    }

    result.add(string.substring(0, index));
    string = string.substring(index + separator.length);
  }

  return result;
}
